@@ -137,8 +137,8 @@ namespace Sass {
               if (List_Obj rest = Cast<List>(a->value())) {
                 arglist->separator(rest->separator());
 
-                for (size_t i = 0, L = rest->size(); i < L; ++i) {
-                  Expression_Obj obj = rest->at(i);
+                for (size_t i = 0, L = rest->length(); i < L; ++i) {
+                  Expression_Obj obj = rest->value_at_index(i);
                   arglist->append(SASS_MEMORY_NEW(Argument,
                                                 obj->pstate(),
                                                 obj,
