@@ -157,7 +157,7 @@ namespace Sass {
         // const Sass::UnitType lhs;
         // const Sass::UnitType rhs;
       public:
-        IncompatibleUnits(const Number& lhs, const Number& rhs);
+        IncompatibleUnits(const Units& lhs, const Units& rhs);
         IncompatibleUnits(const UnitType lhs, const UnitType rhs);
         virtual ~IncompatibleUnits() throw() {};
     };
@@ -200,6 +200,7 @@ namespace Sass {
 
   void warn(std::string msg, ParserState pstate);
   void warn(std::string msg, ParserState pstate, Backtrace* bt);
+  void warning(std::string msg, ParserState pstate);
 
   void deprecated_function(std::string msg, ParserState pstate);
   void deprecated(std::string msg, std::string msg2, ParserState pstate);
