@@ -246,7 +246,7 @@ namespace Sass {
     Expression_Obj val = 0;
 
     if (map) {
-      for (Expression_Obj key : map->keys()) {
+      for (auto __key = (map->keys()).begin(); __key != (map->keys()).end(); ++__key) { Expression_Obj key = *(__key);
         Expression_Obj value = map->at(key);
 
         if (variables.size() == 1) {
@@ -337,15 +337,16 @@ namespace Sass {
     // try to use generic function
     if (env->has("@warn[f]")) {
 
-      // add call stack entry
-      ctx.callee_stack.push_back({
+      struct Sass_Callee callee = {
         "@warn",
         w->pstate().path,
         w->pstate().line + 1,
         w->pstate().column + 1,
         SASS_CALLEE_FUNCTION,
         { env }
-      });
+      };
+      // add call stack entry
+      ctx.callee_stack.push_back(callee);
 
       Definition_Ptr def = Cast<Definition>((*env)["@warn[f]"]);
       // Block_Obj          body   = def->block();
@@ -384,15 +385,16 @@ namespace Sass {
     // try to use generic function
     if (env->has("@error[f]")) {
 
-      // add call stack entry
-      ctx.callee_stack.push_back({
+      struct Sass_Callee callee = {
         "@error",
         e->pstate().path,
         e->pstate().line + 1,
         e->pstate().column + 1,
         SASS_CALLEE_FUNCTION,
         { env }
-      });
+      };
+      // add call stack entry
+      ctx.callee_stack.push_back(callee);
 
       Definition_Ptr def = Cast<Definition>((*env)["@error[f]"]);
       // Block_Obj          body   = def->block();
@@ -428,15 +430,16 @@ namespace Sass {
     // try to use generic function
     if (env->has("@debug[f]")) {
 
-      // add call stack entry
-      ctx.callee_stack.push_back({
+      struct Sass_Callee callee = {
         "@debug",
         d->pstate().path,
         d->pstate().line + 1,
         d->pstate().column + 1,
         SASS_CALLEE_FUNCTION,
         { env }
-      });
+      };
+      // add call stack entry
+      ctx.callee_stack.push_back(callee);
 
       Definition_Ptr def = Cast<Definition>((*env)["@debug[f]"]);
       // Block_Obj          body   = def->block();
@@ -520,7 +523,7 @@ namespace Sass {
     Map_Obj mm = SASS_MEMORY_NEW(Map,
                                 m->pstate(),
                                 m->length());
-    for (auto key : m->keys()) {
+    for (auto __key = (m->keys()).begin(); __key != (m->keys()).end(); ++__key) { auto key = *(__key);
       Expression_Ptr ex_key = key->perform(this);
       Expression_Ptr ex_val = m->at(key);
       if (ex_val == NULL) continue;
@@ -945,7 +948,7 @@ namespace Sass {
     Env* env = environment();
     if (!env->has(full_name) || (!c->via_call() && Prelexer::re_special_fun(name.c_str()))) {
       if (!env->has("*[f]")) {
-        for (Argument_Obj arg : args->elements()) {
+        for (auto __arg = (args->elements()).begin(); __arg != (args->elements()).end(); ++__arg) { Argument_Obj arg = *(__arg);
           if (List_Obj ls = Cast<List>(arg->value())) {
             if (ls->size() == 0) error("() isn't a valid CSS value.", c->pstate());
           }
@@ -1008,14 +1011,15 @@ namespace Sass {
       bind(std::string("Function"), c->name(), params, args, &ctx, &fn_env, this);
       Backtrace here(backtrace(), c->pstate(), ", in function `" + c->name() + "`");
       exp.backtrace_stack.push_back(&here);
-      ctx.callee_stack.push_back({
+      struct Sass_Callee callee = {
         c->name().c_str(),
         c->pstate().path,
         c->pstate().line + 1,
         c->pstate().column + 1,
         SASS_CALLEE_FUNCTION,
         { env }
-      });
+      };
+      ctx.callee_stack.push_back(callee);
 
       // eval the body if user-defined or special, invoke underlying CPP function if native
       if (body /* && !Prelexer::re_special_fun(name.c_str()) */) {
@@ -1049,14 +1053,15 @@ namespace Sass {
 
       Backtrace here(backtrace(), c->pstate(), ", in function `" + c->name() + "`");
       exp.backtrace_stack.push_back(&here);
-      ctx.callee_stack.push_back({
+      struct Sass_Callee callee = {
         c->name().c_str(),
         c->pstate().path,
         c->pstate().line + 1,
         c->pstate().column + 1,
         SASS_CALLEE_C_FUNCTION,
         { env }
-      });
+      };
+      ctx.callee_stack.push_back(callee);
 
       To_C to_c;
       union Sass_Value* c_args = sass_make_list(params->length(), SASS_COMMA);
@@ -1142,7 +1147,7 @@ namespace Sass {
 
     if (Arguments_Ptr args = Cast<Arguments>(ex)) {
       List_Ptr ll = SASS_MEMORY_NEW(List, args->pstate(), 0, SASS_COMMA);
-      for(auto arg : args->elements()) {
+      for (auto __arg = (args->elements()).begin(); __arg != (args->elements()).end(); ++__arg) { auto arg = *(__arg);
         ll->append(arg->value());
       }
       ll->is_interpolant(args->is_interpolant());
@@ -1178,7 +1183,7 @@ namespace Sass {
       List_Obj ll = SASS_MEMORY_NEW(List, l->pstate(), 0, l->separator());
       // this fixes an issue with bourbon sample, not really sure why
       // if (l->size() && Cast<Null>((*l)[0])) { res += ""; }
-      for(Expression_Obj item : *l) {
+      for (auto __item = (l->elements()).begin(); __item != (l->elements()).end(); ++__item) { Expression_Obj item = *(__item);
         item->is_interpolant(l->is_interpolant());
         std::string rl(""); interpolation(ctx, rl, item, into_quotes, l->is_interpolant());
         bool is_null = Cast<Null>(item) != 0; // rl != ""
