@@ -100,7 +100,7 @@ namespace Sass {
   {
     std::string out("");
     bool esc = false;
-    for (auto i : str) {
+    for (auto __i = (str).begin(); __i != (str).end(); ++__i) { auto i = *(__i);
       if (i == '\\') {
         esc = ! esc;
       } else if (esc && i == '\r') {
@@ -127,7 +127,7 @@ namespace Sass {
   {
     std::string out("");
     bool esc = false;
-    for (auto i : str) {
+    for (auto __i = (str).begin(); __i != (str).end(); ++__i) { auto i = *(__i);
       if (i == '\\' && !esc) {
         out += '\\';
         out += '\\';
@@ -168,7 +168,7 @@ namespace Sass {
   {
     std::string out("");
     bool lf = false;
-    for (auto i : str) {
+    for (auto __i = (str).begin(); __i != (str).end(); ++__i) { auto i = *(__i);
       if (i == '\n') {
         out += ' ';
         lf = true;
@@ -186,7 +186,7 @@ namespace Sass {
     size_t has = 0;
     char prev = 0;
     bool clean = false;
-    for (auto i : text) {
+    for (auto __i = (text).begin(); __i != (text).end(); ++__i) { auto i = *(__i);
       if (clean) {
         if (i == '\n') { has = 0; }
         else if (i == '\r') { has = 0; }
